Sybil documentation
===================

This library provides a way to test examples in your documentation by parsing
them from the documentation source and evaluating the parsed examples as part of
your normal test run. Integration is provided for the three main Python test
runners. Sybil is designed so that it's easy to provide your own parsers for
your own types of example in addition to the included parsers for
:mod:`doctest` and :rst:dir:`code-block` examples.

.. toctree::
   :maxdepth: 3

   use.rst
   parsers.rst
   api.rst
   development.rst
   changes.rst
   license.rst

Why Sybil?
==========

Sybil is heavily inspired by `Manuel`__, which was named after a
`Fawlty Towers`__ character, and so it seemed only right to pick another
Fawtly Towers character name for this library.

__ http://pythonhosted.org/manuel/index.html

__ https://en.wikipedia.org/wiki/Fawlty_Towers

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

